@@ -1,4 +1,5 @@
-#![allow(raw_pointer_derive, non_camel_case_types, non_upper_case_globals, non_snake_case)]
+#![no_std]
+#![allow(non_camel_case_types, non_upper_case_globals, non_snake_case)]
 
 extern crate libc;
 
@@ -35,9 +36,14 @@ pub use classobject::*;
 pub use fileobject::*;
 pub use cobject::*;
 pub use pycapsule::*;
-
+pub use traceback::*;
+pub use sliceobject::*;
+pub use cellobject::*;
+pub use iterobject::*;
+pub use genobject::*;
 pub use descrobject::*;
 pub use warnings::*;
+pub use weakrefobject::*;
 pub use pyarena::*;
 pub use modsupport::*;
 pub use pythonrun::*;
@@ -45,8 +51,10 @@ pub use ceval::*;
 pub use import::*;
 pub use objectabstract::*;
 pub use code::*;
+pub use compile::*;
 pub use eval::*;
 pub use structmember::PyMemberDef;
+pub use frameobject::PyFrameObject;
 
 mod pyport;
 mod pymem;
@@ -78,14 +86,14 @@ mod classobject;
 mod fileobject;
 mod cobject;
 mod pycapsule;
-// mod traceback; // TODO: incomplete
-// mod sliceobject; // TODO: incomplete
-// mod cellobject; // TODO: incomplete
-// mod iterobject; // TODO: incomplete
-// mod genobject; // TODO: incomplete
-mod descrobject; // TODO: incomplete
+mod traceback;
+mod sliceobject;
+mod cellobject;
+mod iterobject;
+mod genobject;
+mod descrobject;
 mod warnings;
-// mod weakrefobject; // TODO: incomplete
+mod weakrefobject;
 
 // mod codecs; // TODO: incomplete
 mod pyerrors;
@@ -103,7 +111,7 @@ mod import;
 mod objectabstract;
 
 mod code;
-// mod compile; // TODO: incomplete
+mod compile;
 mod eval;
 
 // mod pyctype; // TODO: incomplete
@@ -115,7 +123,11 @@ mod eval;
 
 // Additional headers that are not exported by Python.h
 pub mod structmember;
+pub mod frameobject;
 
+pub const Py_single_input: libc::c_int = 256;
+pub const Py_file_input: libc::c_int = 257;
+pub const Py_eval_input: libc::c_int = 258;
 
 #[cfg(not(py_sys_config="Py_USING_UNICODE"))]
 #[inline(always)]
