@@ -243,6 +243,48 @@ impl Clone for PyNumberMethods {
     #[inline] fn clone(&self) -> PyNumberMethods { *self }
 }
 
+pub const PyNumberMethods_INIT : PyNumberMethods = PyNumberMethods {
+    nb_add: None,
+    nb_subtract: None,
+    nb_multiply: None,
+    nb_divide: None,
+    nb_remainder: None,
+    nb_divmod: None,
+    nb_power: None,
+    nb_negative: None,
+    nb_positive: None,
+    nb_absolute: None,
+    nb_nonzero: None,
+    nb_invert: None,
+    nb_lshift: None,
+    nb_rshift: None,
+    nb_and: None,
+    nb_xor: None,
+    nb_or: None,
+    nb_coerce: None,
+    nb_c_int: None,
+    nb_long: None,
+    nb_float: None,
+    nb_oct: None,
+    nb_hex: None,
+    nb_inplace_add: None,
+    nb_inplace_subtract: None,
+    nb_inplace_multiply: None,
+    nb_inplace_divide: None,
+    nb_inplace_remainder: None,
+    nb_inplace_power: None,
+    nb_inplace_lshift: None,
+    nb_inplace_rshift: None,
+    nb_inplace_and: None,
+    nb_inplace_xor: None,
+    nb_inplace_or: None,
+    nb_floor_divide: None,
+    nb_true_divide: None,
+    nb_inplace_floor_divide: None,
+    nb_inplace_true_divide: None,
+    nb_index: None,
+};
+
 #[repr(C)]
 #[derive(Copy)]
 pub struct PySequenceMethods {
@@ -262,6 +304,19 @@ impl Clone for PySequenceMethods {
     #[inline] fn clone(&self) -> PySequenceMethods { *self }
 }
 
+pub const PySequenceMethods_INIT : PySequenceMethods = PySequenceMethods {
+    sq_length: None,
+    sq_concat: None,
+    sq_repeat: None,
+    sq_item: None,
+    sq_slice: None,
+    sq_ass_item: None,
+    sq_ass_slice: None,
+    sq_contains: None,
+    sq_inplace_concat: None,
+    sq_inplace_repeat: None,
+};
+
 #[repr(C)]
 #[derive(Copy)]
 pub struct PyMappingMethods {
@@ -274,6 +329,12 @@ impl Clone for PyMappingMethods {
     #[inline] fn clone(&self) -> PyMappingMethods { *self }
 }
 
+pub const PyMappingMethods_INIT : PyMappingMethods = PyMappingMethods {
+    mp_length: None,
+    mp_subscript: None,
+    mp_ass_subscript: None,
+};
+
 #[repr(C)]
 #[derive(Copy)]
 pub struct PyBufferProcs {
@@ -289,6 +350,15 @@ impl Clone for PyBufferProcs {
     #[inline] fn clone(&self) -> PyBufferProcs { *self }
 }
 
+pub const PyBufferProcs_INIT : PyBufferProcs = PyBufferProcs {
+    bf_getreadbuffer: None,
+    bf_getwritebuffer: None,
+    bf_getsegcount: None,
+    bf_getcharbuffer: None,
+    bf_getbuffer: None,
+    bf_releasebuffer: None,
+};
+
 pub type freefunc =
     unsafe extern "C" fn(arg1: *mut c_void);
 pub type destructor =
@@ -413,6 +483,114 @@ impl Clone for PyTypeObject {
     #[inline] fn clone(&self) -> PyTypeObject { *self }
 }
 
+#[cfg(py_sys_config="Py_TRACE_REFS")]
+pub const PyTypeObject_INIT : PyTypeObject = PyTypeObject {
+    _ob_next: 0 as *mut PyObject,
+    _ob_prev: 0 as *mut PyObject,
+    ob_refcnt: 1,
+    ob_type: 0 as *mut PyTypeObject,
+    ob_size: 0,
+    tp_name: 0 as *const c_char,
+    tp_basicsize: 0,
+    tp_itemsize: 0,
+    tp_dealloc: None,
+    tp_print: None,
+    tp_getattr: None,
+    tp_setattr: None,
+    tp_compare: None,
+    tp_repr: None,
+    tp_as_number: 0 as *mut PyNumberMethods,
+    tp_as_sequence: 0 as *mut PySequenceMethods,
+    tp_as_mapping: 0 as *mut PyMappingMethods,
+    tp_hash: None,
+    tp_call: None,
+    tp_str: None,
+    tp_getattro: None,
+    tp_setattro: None,
+    tp_as_buffer: 0 as *mut PyBufferProcs,
+    tp_flags: Py_TPFLAGS_DEFAULT,
+    tp_doc: 0 as *const c_char,
+    tp_traverse: None,
+    tp_clear: None,
+    tp_richcompare: None,
+    tp_weaklistoffset: 0,
+    tp_iter: None,
+    tp_iternext: None,
+    tp_methods: 0 as *mut PyMethodDef,
+    tp_members: 0 as *mut ::structmember::PyMemberDef,
+    tp_getset: 0 as *mut ::descrobject::PyGetSetDef,
+    tp_base: 0 as *mut PyTypeObject,
+    tp_dict: 0 as *mut PyObject,
+    tp_descr_get: None,
+    tp_descr_set: None,
+    tp_dictoffset: 0,
+    tp_init: None,
+    tp_alloc: None,
+    tp_new: None,
+    tp_free: None,
+    tp_is_gc: None,
+    tp_bases: 0 as *mut PyObject,
+    tp_mro: 0 as *mut PyObject,
+    tp_cache: 0 as *mut PyObject,
+    tp_subclasses: 0 as *mut PyObject,
+    tp_weaklist: 0 as *mut PyObject,
+    tp_del: None,
+    tp_version_tag: 0,
+};
+
+#[cfg(not(py_sys_config="Py_TRACE_REFS"))]
+pub const PyTypeObject_INIT : PyTypeObject = PyTypeObject {
+    ob_refcnt: 1,
+    ob_type: 0 as *mut PyTypeObject,
+    ob_size: 0,
+    tp_name: 0 as *const c_char,
+    tp_basicsize: 0,
+    tp_itemsize: 0,
+    tp_dealloc: None,
+    tp_print: None,
+    tp_getattr: None,
+    tp_setattr: None,
+    tp_compare: None,
+    tp_repr: None,
+    tp_as_number: 0 as *mut PyNumberMethods,
+    tp_as_sequence: 0 as *mut PySequenceMethods,
+    tp_as_mapping: 0 as *mut PyMappingMethods,
+    tp_hash: None,
+    tp_call: None,
+    tp_str: None,
+    tp_getattro: None,
+    tp_setattro: None,
+    tp_as_buffer: 0 as *mut PyBufferProcs,
+    tp_flags: Py_TPFLAGS_DEFAULT,
+    tp_doc: 0 as *const c_char,
+    tp_traverse: None,
+    tp_clear: None,
+    tp_richcompare: None,
+    tp_weaklistoffset: 0,
+    tp_iter: None,
+    tp_iternext: None,
+    tp_methods: 0 as *mut PyMethodDef,
+    tp_members: 0 as *mut ::structmember::PyMemberDef,
+    tp_getset: 0 as *mut ::descrobject::PyGetSetDef,
+    tp_base: 0 as *mut PyTypeObject,
+    tp_dict: 0 as *mut PyObject,
+    tp_descr_get: None,
+    tp_descr_set: None,
+    tp_dictoffset: 0,
+    tp_init: None,
+    tp_alloc: None,
+    tp_new: None,
+    tp_free: None,
+    tp_is_gc: None,
+    tp_bases: 0 as *mut PyObject,
+    tp_mro: 0 as *mut PyObject,
+    tp_cache: 0 as *mut PyObject,
+    tp_subclasses: 0 as *mut PyObject,
+    tp_weaklist: 0 as *mut PyObject,
+    tp_del: None,
+    tp_version_tag: 0,
+};
+
 #[repr(C)]
 #[derive(Copy)]
 pub struct PyHeapTypeObject {
@@ -436,7 +614,7 @@ pub unsafe fn PyHeapType_GET_MEMBERS(etype: *mut PyHeapTypeObject) -> *mut ::str
     (etype as *mut u8).offset(basicsize as isize) as *mut ::structmember::PyMemberDef
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyType_IsSubtype(a: *mut PyTypeObject, b: *mut PyTypeObject) -> c_int;
 }
 
@@ -445,7 +623,7 @@ pub unsafe fn PyObject_TypeCheck(ob: *mut PyObject, tp: *mut PyTypeObject) -> c_
     (Py_TYPE(ob) == tp || PyType_IsSubtype(Py_TYPE(ob), tp) != 0) as c_int
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub static mut PyType_Type: PyTypeObject;
     pub static mut PyBaseObject_Type: PyTypeObject;
     pub static mut PySuper_Type: PyTypeObject;
@@ -461,7 +639,7 @@ pub unsafe fn PyType_CheckExact(op: *mut PyObject) -> c_int {
     (Py_TYPE(op) == (&mut PyType_Type as *mut _)) as c_int
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyType_Ready(t: *mut PyTypeObject) -> c_int;
     pub fn PyType_GenericAlloc(t: *mut PyTypeObject, nitems: Py_ssize_t)
      -> *mut PyObject;
@@ -488,7 +666,7 @@ pub unsafe fn PyObject_Bytes(o: *mut PyObject) -> *mut PyObject {
     PyObject_Str(o)
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     #[cfg(py_sys_config="Py_USING_UNICODE")]
     pub fn PyObject_Unicode(o: *mut PyObject) -> *mut PyObject;
     
@@ -684,7 +862,7 @@ pub unsafe fn Py_XDECREF(op : *mut PyObject) {
     }
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn Py_IncRef(o: *mut PyObject);
     pub fn Py_DecRef(o: *mut PyObject);
 
@@ -710,7 +888,7 @@ pub const Py_NE : c_int = 3;
 pub const Py_GT : c_int = 4;
 pub const Py_GE : c_int = 5;
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     fn _PyTrash_thread_deposit_object(o: *mut PyObject);
     fn _PyTrash_thread_destroy_chain();
 }
